@@ -1,9 +1,10 @@
 package Zonemaster::Test::Address v1.0.1;
 
-use 5.14.2;
 use strict;
 use warnings;
 
+use 5.014002;
+
 use Zonemaster;
 use Zonemaster::Util;
 use Zonemaster::TestMethods;
@@ -20,11 +21,11 @@ sub all {
     my ( $class, $zone ) = @_;
     my @results;
 
-    push @results, $class->address01( $zone ) if Zonemaster->config->should_run('address01');
-    push @results, $class->address02( $zone ) if Zonemaster->config->should_run('address02');
+    push @results, $class->address01( $zone ) if Zonemaster->config->should_run( 'address01' );
+    push @results, $class->address02( $zone ) if Zonemaster->config->should_run( 'address02' );
     # Perform ADDRESS03 if ADDRESS02 passed
     if ( any { $_->tag eq q{NAMESERVERS_IP_WITH_REVERSE} } @results ) {
-        push @results, $class->address03( $zone ) if Zonemaster->config->should_run('address03');
+        push @results, $class->address03( $zone ) if Zonemaster->config->should_run( 'address03' );
     }
 
     return @results;
@@ -142,23 +143,28 @@ sub address02 {
     my @results;
 
     my %ips;
+    my $ptr_query;
 
-    foreach my $local_ns ( @{ Zonemaster::TestMethods->method5( $zone ) } ) {
+    foreach
+      my $local_ns ( @{ Zonemaster::TestMethods->method4( $zone ) }, @{ Zonemaster::TestMethods->method5( $zone ) } )
+    {
 
         next if $ips{ $local_ns->address->short };
 
         my $reverse_ip_query = $local_ns->address->reverse_ip;
+        $ptr_query = $reverse_ip_query;
 
-        my $p = Zonemaster::Recursor->recurse( $reverse_ip_query, q{PTR} );
+        my $p = Zonemaster::Recursor->recurse( $ptr_query, q{PTR} );
+
+        # In case of Classless IN-ADDR.ARPA delegation, query returns
+        # CNAME records. A PTR query is done on the CNAME.
+        if ( $p and $p->rcode eq q{NOERROR} and $p->get_records( q{CNAME}, q{answer} ) ) {
+            my ( $cname ) = $p->get_records( q{CNAME}, q{answer} );
+            $ptr_query = $cname->cname;
+            $p = Zonemaster::Recursor->recurse( $ptr_query, q{PTR} );
+        }
 
         if ( $p ) {
-            # In case of Classless IN-ADDR.ARPA delegation, query returns
-            # CNAME records. A PTR query is done on the CNAME.
-            if ($p->rcode eq q{NOERROR} and $p->get_records( q{CNAME}, q{answer} ) ) {
-                my ( $cname ) = $p->get_records( q{CNAME}, q{answer} );
-                $p = Zonemaster::Recursor->recurse( $cname->cname, q{PTR} );
-            }
-
             if ( $p->rcode ne q{NOERROR} or not $p->get_records( q{PTR}, q{answer} ) ) {
                 push @results,
                   info(
@@ -173,7 +179,7 @@ sub address02 {
             push @results,
               info(
                 NO_RESPONSE_PTR_QUERY => {
-                    reverse => $reverse_ip_query,
+                    reverse => $ptr_query,
                 }
               );
         }
@@ -207,7 +213,7 @@ sub address03 {
 
         # In case of Classless IN-ADDR.ARPA delegation, query returns
         # CNAME records. A PTR query is done on the CNAME.
-        if ($p->rcode eq q{NOERROR} and $p->get_records( q{CNAME}, q{answer} ) ) {
+        if ( $p and $p->rcode eq q{NOERROR} and $p->get_records( q{CNAME}, q{answer} ) ) {
             my ( $cname ) = $p->get_records( q{CNAME}, q{answer} );
             $ptr_query = $cname->cname;
             $p = Zonemaster::Recursor->recurse( $ptr_query, q{PTR} );
@@ -241,7 +247,7 @@ sub address03 {
             push @results,
               info(
                 NO_RESPONSE_PTR_QUERY => {
-                    reverse => $reverse_ip_query,
+                    reverse => $ptr_query,
                 }
               );
         }
